# Changelog for decorate-me

Adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html),
[Keep a Changelog](https://keepachangelog.com/en/1.0.0/) recommendations,
and [Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0/).


## [0.1.0] - 2020-05-18

### Added:
- Stub files.
